==> 0.0.2.tar.gz: lib/flutter_socket_io.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class FlutterSocketIO {

  static const MethodChannel _channel = const MethodChannel('flutter_socket_io');
  
  static void setMethodCallHandler(Future<dynamic> handler(MethodCall call)) {
    _channel.setMethodCallHandler(handler);
  }
  static void connectSocket(String socketChannel, [String socketStatusCallback]) async {
    await _channel.invokeMethod(
        MethodCallName.SOCKET_CONNECT,
        {
          MethodCallArgumentsName.SOCKET_CHANNEL : socketChannel,
          MethodCallArgumentsName.SOCKET_STATUS_CALLBACK : socketStatusCallback
        });
  }

  /// Map subscribes (Map<String, String>): key is event name, value [optional] is callback event function
  ///
  static void socketSubscribes(Map<String, String> subscribes) async {
    await _channel.invokeMethod(MethodCallName.SOCKET_SUBSCRIBES, subscribes);
  }

  /// Map unsubscribes: key is event name, value [optional] is callback event function
  ///
  static void socketUnsubscribes(Map<String, String> unsubscribes) async {
    await _channel.invokeMethod(MethodCallName.SOCKET_UNSUBSCRIBES, unsubscribes);
  }

  static void sendMessage(String event, String message) async {
    await _channel.invokeMethod(
        MethodCallName.SOCKET_SEND_MESSAGE,
        {
          MethodCallArgumentsName.SOCKET_EVENT : event,
          MethodCallArgumentsName.SOCKET_MESSAGE : message
        });
  }

  static void disconnectSocket() async {
    await _channel.invokeMethod(MethodCallName.SOCKET_DISCONNECT);
  }

}

class MethodCallArgumentsName {
  static final String SOCKET_CHANNEL = "socketChannel";
  static final String SOCKET_STATUS_CALLBACK = "socketStatusCallback";
  static final String SOCKET_EVENT = "socketEvent";
  static final String SOCKET_MESSAGE = "socketMessage";
}

class MethodCallName {
  static final String SOCKET_CONNECT = "socketConnect";
  static final String SOCKET_DISCONNECT = "socketDisconnect";
  static final String SOCKET_SUBSCRIBES = "socketSubcribes";
  static final String SOCKET_UNSUBSCRIBES = "socketUnsubcribes";
  static final String SOCKET_SEND_MESSAGE = "socketSendMessage";
}

==> 0.0.3.tar.gz: lib/flutter_socket_io.dart <==
import 'dart:async';

import 'package:flutter/services.dart';
import 'package:flutter_socket_io/iflutter_socket_io.dart';

class FlutterSocketIO implements IFlutterSocketIO {

  static const MethodChannel _channel = const MethodChannel('flutter_socket_io');
  String _socketNameSpace;
  String _socketStatusCallback;

  FlutterSocketIO(String socketNameSpace, String socketStatusCallback,
      Future<dynamic> handler(MethodCall call)) {
    _socketNameSpace = socketNameSpace;
    _socketStatusCallback = socketStatusCallback;
    _channel.setMethodCallHandler(handler);
  }


  @override
  void connectSocket() async {
    await _channel.invokeMethod(
        MethodCallName.SOCKET_CONNECT,
        {
          MethodCallArgumentsName.SOCKET_NAME_SPACE : _socketNameSpace,
          MethodCallArgumentsName.SOCKET_STATUS_CALLBACK : _socketStatusCallback
        });
  }

  /// Map subscribes (Map<String, String>): key is event name, value [optional] is callback event function
  ///
  @override
  void subscribes(Map<String, String> subscribes) async {
    await _channel.invokeMethod(MethodCallName.SOCKET_SUBSCRIBES, subscribes);
  }

  @override
  void sendMessage(String event, String message) async {
    await _channel.invokeMethod(
        MethodCallName.SOCKET_SEND_MESSAGE,
        {
          MethodCallArgumentsName.SOCKET_EVENT : event,
          MethodCallArgumentsName.SOCKET_MESSAGE : message
        });
  }

  /// Map unsubscribes: key is event name, value [optional] is callback event function
  ///
  @override
  void unSubscribes(Map<String, String> unsubscribes) async {
    await _channel.invokeMethod(MethodCallName.SOCKET_UNSUBSCRIBES, unsubscribes);
  }

  @override
  void disconnect() async {
    await _channel.invokeMethod(MethodCallName.SOCKET_DISCONNECT);
  }

}

class MethodCallArgumentsName {
  static final String SOCKET_NAME_SPACE = "socketNameSpace";
  static final String SOCKET_STATUS_CALLBACK = "socketStatusCallback";
  static final String SOCKET_EVENT = "socketEvent";
  static final String SOCKET_MESSAGE = "socketMessage";
}

class MethodCallName {
  static final String SOCKET_CONNECT = "socketConnect";
  static final String SOCKET_DISCONNECT = "socketDisconnect";
  static final String SOCKET_SUBSCRIBES = "socketSubcribes";
  static final String SOCKET_UNSUBSCRIBES = "socketUnsubcribes";
  static final String SOCKET_SEND_MESSAGE = "socketSendMessage";
}
